@@ -51,7 +51,7 @@ public:
     /// \param offset The offsets of the rows. Row i starts
     ///               at offset[i] and ends a offset[i+1]
     /// \param size   The number of entries/rows of the table
-    SparseTableView(int* data, int *offset, std::size_t size_arg)
+    SparseTableView(int* data, unsigned *offset, std::size_t size_arg)
         : data_(data), offset_(offset), size_(size_arg)
     {}
 
@@ -84,7 +84,7 @@ private:
     /// \brief offset The offsets of the rows.
     ///
     /// Row i starts at offset[i] and ends a offset[i+1]
-    const int* offset_;
+    const unsigned* offset_;
     /// \brief The size, i.e. the number of rows.
     std::size_t size_;
 };
@@ -317,7 +317,7 @@ const double* vertexCoordinates(const UnstructuredGrid& grid, int index);
 class FaceCellsProxy
 {
 public:
-    FaceCellsProxy(const UnstructuredGrid& grid)
+    explicit FaceCellsProxy(const UnstructuredGrid& grid)
     : face_cells_(grid.face_cells)
     {}
     int operator()(int face_index, int local_index) const
@@ -370,7 +370,7 @@ T increment(const T& t, int i, int)
 /// \param i The index of the coordinate.
 /// \tparam T The type of the coordinate of the centroid.
 template<class T>
-double getCoordinate(T* cc, int i)
+double getCoordinate(const T* cc, int i)
 {
     return cc[i];
 }
