@@ -225,8 +225,8 @@ process_vertical_faces(int direction,
     int i,j;
     int *cornerpts[4];
     int d[3];
-    int f;
-    enum face_tag tag[] = { I_FACE, J_FACE };
+    unsigned f;
+    const enum face_tag tag[] = { I_FACE, J_FACE };
     int *tmp;
     int nx = out->dimensions[0];
     int ny = out->dimensions[1];
@@ -458,7 +458,7 @@ process_horizontal_faces(int **intersections,
   pt holds coordinates to intersection between lines given by point
   numbers L[0]-L[1] and L[2]-L[3].
 */
-static void approximate_intersection_pt(int *L, double *c, double *pt)
+static void approximate_intersection_pt(const int* L, const double* c, double* pt)
 {
     double a;
     double z0, z1, z2, z3;
@@ -1065,7 +1065,8 @@ static void
 reverse_face_nodes(struct processed_grid *out)
 /* ---------------------------------------------------------------------- */
 {
-    int f, t, *i, *j;
+    int t, *i, *j;
+    unsigned f;
 
     for (f = 0; f < out->number_of_faces; f++) {
         i = out->face_nodes + (out->face_ptr[f + 0] + 0);
