@@ -96,15 +96,6 @@ template<int> class EntityRep;
 }
 }
 
-
-void markAndAdapt_check(Dune::CpGrid&,
-                        const std::array<int,3>&,
-                        const std::vector<int>&,
-                        Dune::CpGrid&,
-                        bool,
-                        bool,
-                        bool);
-
 void refine_and_check(const Dune::cpgrid::Geometry<3, 3>&,
                       const std::array<int, 3>&,
                       bool);
@@ -122,7 +113,7 @@ void refinePatch_and_check(Dune::CpGrid&,
 void check_global_refine(const Dune::CpGrid&,
                          const Dune::CpGrid&);
 
-void fieldProp_check(const Dune::CpGrid& grid, Opm::EclipseGrid eclGrid, std::string deck_string);
+void fieldProp_check(const Dune::CpGrid& grid, Opm::EclipseGrid eclGrid, const std::string& deck_string);
 
 void testInactiveCellsLgrs(const std::string&,
                            const std::vector<std::array<int,3>>&,
@@ -152,15 +143,6 @@ class CpGridData
     friend class Dune::cpgrid::IdSet;
     friend class Dune::cpgrid::LevelGlobalIdSet;
 
-    friend
-    void ::markAndAdapt_check(Dune::CpGrid&,
-                              const std::array<int,3>&,
-                              const std::vector<int>&,
-                              Dune::CpGrid&,
-                              bool,
-                              bool,
-                              bool);
-
     friend
     void ::refine_and_check(const Dune::cpgrid::Geometry<3, 3>&,
                             const std::array<int, 3>&,
@@ -181,7 +163,7 @@ class CpGridData
     void ::check_global_refine(const Dune::CpGrid&,
                                const Dune::CpGrid&);
     friend
-    void ::fieldProp_check(const Dune::CpGrid& grid, Opm::EclipseGrid eclGrid, std::string deck_string);
+    void ::fieldProp_check(const Dune::CpGrid& grid, Opm::EclipseGrid eclGrid, const std::string& deck_string);
     friend
     void ::testInactiveCellsLgrs(const std::string&,
                                  const std::vector<std::array<int,3>>&,
@@ -209,7 +191,9 @@ public:
         /// communicating. Uses the define MAX_DATA_COMMUNICATED_PER_ENTITY.
         MAX_DATA_PER_CELL = MAX_DATA_COMMUNICATED_PER_ENTITY
 #endif
-    };     
+    };
+
+    CpGridData() = delete;
 
     /// Constructor for parallel grid data.
     /// \param comm The MPI communicator
@@ -308,8 +292,29 @@ public:
         ijk = getIJK(global_cell_[c], logical_cartesian_size_);
     }
 
+    int cellFace(int cell, int local_index) const
+    {
+        return cell_to_face_[cpgrid::EntityRep<0>(cell, true)][local_index].index();
+    }
+
+    int faceToCellSize(int face) const {
+        Dune::cpgrid::EntityRep<1> faceEntity(face, true);
+        return face_to_cell_[faceEntity].size();
+    }
+
+    /// Return global_cell_ of any level grid, or the leaf grid view (in presence of refinement).
+    /// global_cell_ has size number of cells present on a process and maps to the underlying Cartesian Grid.
+    ///
+    /// Note: CpGrid::globalCell() returns current_view_data_-> global_cell_ (current_view_data_ points at
+    /// data_.back() or distributed_data_.back(), in general. If the grid has been refined, current_view_data_
+    /// points at the "leaf grid view").
+    const std::vector<int>& globalCell() const
+    {
+        return  global_cell_;
+    }
+
     /// @brief Extract Cartesian index triplet (i,j,k) given an index between 0 and NXxNYxNZ -1
-    ///        where NX, NY, and NZ is the total amoung of cells in each direction x-,y-,and z- respectively.
+    ///    where NX, NY, and NZ is the total amoung of cells in each direction x-,y-,and z- respectively.
     ///
     /// @param [in] idx      Integer between 0 and cells_per_dim[0]*cells_per_dim[1]*cells_per_dim[2]-1
     /// @param [in] cells_per_dim
@@ -353,9 +358,9 @@ public:
     /// @brief Check startIJK and endIJK of each patch of cells to be refined are valid, i.e.
     ///        startIJK and endIJK vectors have the same size and, startIJK < endIJK coordenate by coordenate.
     ///
-    /// @param [in]  startIJK_vec  Vector of Cartesian triplet indices where each patch starts.
-    /// @param [in]  endIJK_vec    Vector of Cartesian triplet indices where each patch ends.
-    ///                            Last cell part of the lgr will be {endIJK_vec[patch][0]-1, ..., endIJK_vec[patch][2]-1}.
+    /// @param [in]  startIJK_vec       Vector of Cartesian triplet indices where each patch starts.
+    /// @param [in]  endIJK_vec         Vector of Cartesian triplet indices where each patch ends.
+    ///                                 Last cell part of the lgr will be {endIJK_vec[patch][0]-1, ..., endIJK_vec[patch][2]-1}.
     void validStartEndIJKs(const std::vector<std::array<int,3>>& startIJK_vec, const std::vector<std::array<int,3>>& endIJK_vec) const;
 
     /// @brief Check that every cell to be refined has cuboid shape.
@@ -401,6 +406,25 @@ public:
     void postAdapt();
 
 private:
+    /// @brief Check compatibility of number of subdivisions of neighboring LGRs.
+    ///
+    /// Check shared faces on boundaries of LGRs. Not optimal since the code below does not take into account
+    /// active/inactive cells, instead, relies on "ijk-computations".
+    ///
+    /// @param [in]  cells_per_dim_vec    Vector of expected subdivisions per cell, per direction, in each LGR.
+    /// @param [in]  startIJK_vec         Vector of Cartesian triplet indices where each patch starts.
+    /// @param [in]  endIJK_vec           Vector of Cartesian triplet indices where each patch ends.
+    ///                                   Last cell part of the lgr will be {endIJK_vec[patch][0]-1, ..., endIJK_vec[patch][2]-1}.
+    /// @return True if all block of cells either do not share faces on their boundaries, or they may share faces with compatible
+    ///         subdivisions. Example: block1 and block2 share an I_FACE, then number of subdivisions NY NZ should coincide, i.e.
+    ///         if block1, block2 cells_per_dim values are {NX1, NY1, NZ1}, {NX2, NY2, NZ2}, respectively, then NY1 == NY2 and
+    ///         NZ1 == Nz2.
+    ///         False if at least two blocks share a face and their subdivions are not compatible. In the example above,
+    ///         if NY1 != NY2 or NZ1 != NZ2.
+    bool compatibleSubdivisions(const std::vector<std::array<int,3>>& cells_per_dim_vec,
+                                const std::vector<std::array<int,3>>& startIJK_vec,
+                                const std::vector<std::array<int,3>>& endIJK_vec) const;
+
     std::array<Dune::FieldVector<double,3>,8> getReferenceRefinedCorners(int idx_in_parent_cell, const std::array<int,3>& cells_per_dim) const;
 
     /// @brief Compute amount of cells in each direction of a patch of cells. (Cartesian grid required).
@@ -501,12 +525,28 @@ public:
         return level_;
     }
     /// Add doc/or remove method and replace it with better approach
-    std::vector<std::shared_ptr<Dune::cpgrid::CpGridData>> levelData() const
+    const std::vector<std::shared_ptr<Dune::cpgrid::CpGridData>>& levelData() const
     {
+        if (level_data_ptr_->empty()) {
+            OPM_THROW(std::logic_error, "Level data has not been initialized\n");
+        }
         return *level_data_ptr_;
     }
 
+    /// @brief Retrieves the level and child indices of a given parent cell.
+    ///
+    /// @param elemIdx The index of the parent cell.
+    /// @return A tuple of (- could be a  pair -)
+    ///         - An integer representing the refinement level (LGR) of the parent cell.
+    ///         - A vector of integers representing the indices of the child cells.
+    ///         - If the parent cell has no children, the entry is {-1, {}}.
+    const std::tuple<int,std::vector<int>>& getChildrenLevelAndIndexList(int elemIdx) const {
+        return parent_to_children_cells_[elemIdx];
+    }
 
+    const std::vector<std::tuple<int,std::vector<int>>>& getParentToChildren() const {
+        return parent_to_children_cells_;
+    }
     /// @brief Refine a single cell and return a shared pointer of CpGridData type.
     ///
     /// refineSingleCell() takes a cell and refines it in a chosen amount of cells (per direction); creating the
@@ -655,10 +695,10 @@ public:
     /// \brief The type of the collective communication.
     using Communication = CpGridDataTraits::Communication;
     using CollectiveCommunication = CpGridDataTraits::CollectiveCommunication;
-#if HAVE_MPI
+
     /// \brief The type of the set of the attributes
     using AttributeSet = CpGridDataTraits::AttributeSet;
-
+#if HAVE_MPI
     /// \brief The type of the  Communicator.
     using Communicator = CpGridDataTraits::Communicator;
 
@@ -751,8 +791,8 @@ private:
     /// \param distributed_view The view of the distributed grid.
     /// \tparam DataHandle The type of the data handle used.
     template<class DataHandle>
-    void scatterData(DataHandle& data, CpGridData* global_data,
-                     CpGridData* distributed_data, const InterfaceMap& cell_inf,
+    void scatterData(DataHandle& data, const CpGridData* global_data,
+                     const CpGridData* distributed_data, const InterfaceMap& cell_inf,
                      const InterfaceMap& point_inf);
 
     /// \brief Scatter data specific to given codimension from a global grid representation
@@ -792,7 +832,7 @@ private:
 
 #endif
 
-    void computeGeometry(CpGrid& grid,
+    void computeGeometry(const CpGrid& grid,
                          const DefaultGeometryPolicy&  globalGeometry,
                          const std::vector<int>& globalAquiferCells,
                          const OrientedEntityTable<0, 1>& globalCell2Faces,
@@ -1044,7 +1084,7 @@ struct Mover
 template<class DataHandle>
 struct BaseMover
 {
-    BaseMover(DataHandle& data)
+    explicit BaseMover(DataHandle& data)
     : data_(data)
     {}
     template<class E>
@@ -1064,8 +1104,8 @@ struct BaseMover
 template<class DataHandle>
 struct Mover<DataHandle,0> : public BaseMover<DataHandle>
 {
-    Mover<DataHandle,0>(DataHandle& data, CpGridData* gatherView,
-                        CpGridData* scatterView)
+    Mover(DataHandle& data, CpGridData* gatherView,
+          CpGridData* scatterView)
     : BaseMover<DataHandle>(data), gatherView_(gatherView), scatterView_(scatterView)
     {}
 
@@ -1082,8 +1122,8 @@ struct Mover<DataHandle,0> : public BaseMover<DataHandle>
 template<class DataHandle>
 struct Mover<DataHandle,1> : public BaseMover<DataHandle>
 {
-    Mover<DataHandle,1>(DataHandle& data, CpGridData* gatherView,
-                        CpGridData* scatterView)
+    Mover(DataHandle& data, CpGridData* gatherView,
+          CpGridData* scatterView)
     : BaseMover<DataHandle>(data), gatherView_(gatherView), scatterView_(scatterView)
     {}
 
@@ -1092,7 +1132,7 @@ struct Mover<DataHandle,1> : public BaseMover<DataHandle>
         typedef typename OrientedEntityTable<0,1>::row_type row_type;
         EntityRep<0> from_cell=EntityRep<0>(from_cell_index, true);
         EntityRep<0> to_cell=EntityRep<0>(to_cell_index, true);
-        OrientedEntityTable<0,1>& table = gatherView_->cell_to_face_;
+        const OrientedEntityTable<0,1>& table = gatherView_->cell_to_face_;
         row_type from_faces=table.operator[](from_cell);
         row_type to_faces=scatterView_->cell_to_face_[to_cell];
 
@@ -1106,8 +1146,8 @@ struct Mover<DataHandle,1> : public BaseMover<DataHandle>
 template<class DataHandle>
 struct Mover<DataHandle,3> : public BaseMover<DataHandle>
 {
-    Mover<DataHandle,3>(DataHandle& data, CpGridData* gatherView,
-                        CpGridData* scatterView)
+    Mover(DataHandle& data, CpGridData* gatherView,
+          CpGridData* scatterView)
     : BaseMover<DataHandle>(data), gatherView_(gatherView), scatterView_(scatterView)
     {}
     void operator()(std::size_t from_cell_index,std::size_t to_cell_index)
@@ -1129,8 +1169,8 @@ struct Mover<DataHandle,3> : public BaseMover<DataHandle>
 } // end mover namespace
 
 template<class DataHandle>
-void CpGridData::scatterData(DataHandle& data, CpGridData* global_data,
-                             CpGridData* distributed_data, const InterfaceMap& cell_inf,
+void CpGridData::scatterData(DataHandle& data, const CpGridData* global_data,
+                             const CpGridData* distributed_data, const InterfaceMap& cell_inf,
                              const InterfaceMap& point_inf)
 {
 #if HAVE_MPI
@@ -1149,7 +1189,7 @@ void CpGridData::scatterData(DataHandle& data, CpGridData* global_data,
 
 template<int codim, class DataHandle>
 void CpGridData::scatterCodimData(DataHandle& data, CpGridData* global_data,
-                          CpGridData* distributed_data)
+                                  CpGridData* distributed_data)
 {
     CpGridData *gather_view, *scatter_view;
     gather_view=global_data;
