@@ -24,8 +24,6 @@
 #include <functional>
 
 #include <opm/grid/GridHelpers.hpp>
-#include <opm/grid/utility/OpmParserIncludes.hpp>
-
 
 #include <opm/grid/utility/platform_dependent/disable_warnings.h>
 
@@ -223,7 +221,7 @@ class FaceVerticesContainerProxy
 public:
     /// \brief Constructor.
     /// \param grid The grid whose information we represent.
-    FaceVerticesContainerProxy(const Dune::CpGrid* grid)
+    explicit FaceVerticesContainerProxy(const Dune::CpGrid* grid)
         : LocalIndexContainerProxy<&Dune::CpGrid::faceVertex, &Dune::CpGrid::numFaceVertices>(grid)
     {}
 };
@@ -304,7 +302,7 @@ public:
 
     Cell2FacesRow operator[](int cell_index) const
     {
-        auto& row=grid_->cellFaceRow(cell_index);
+        const auto& row = grid_->cellFaceRow(cell_index);
         return Cell2FacesRow(row, cell_index);
     }
 
@@ -407,13 +405,13 @@ const int* cartDims(const Dune::CpGrid& grid);
 /// in the underlying structured grid.
 const int*  globalCell(const Dune::CpGrid&);
 
+#if HAVE_ECL_INPUT
 /// \brief Create Eclipse style ACTNUM array.
 ///
 /// Create a vector with global cartesian number of elements,
 /// the value is 0 for inactive cells and one for active cells.
 std::vector<int> createACTNUM(const Dune::CpGrid& grid);
 
-#if HAVE_ECL_INPUT
 /// Construct an EclipseGrid instance based on the inputGrid, with modifications to
 /// zcorn and actum from the dune CPGrid
 EclipseGrid createEclipseGrid(const Dune::CpGrid& grid, const EclipseGrid& inputGrid);
