@@ -41,7 +41,10 @@ along with OPM.  If not, see <http://www.gnu.org/licenses/>.
 #include "GlobalIdMapping.hpp"
 #include "Intersection.hpp"
 
+#include <cstdint>
 #include <unordered_map>
+#include <utility>
+
 namespace Dune
 {
     namespace cpgrid
@@ -54,7 +57,7 @@ namespace Dune
         public:
             /// @brief
             /// @todo Doc me!
-            typedef int IndexType;
+            typedef std::int64_t IndexType;
 
             /** \brief Export the type of the entity used as parameter in the index(...) method */
             template <int cc>
@@ -198,9 +201,9 @@ namespace Dune
             friend class Dune::cpgrid::CpGridData;
             //friend class Dune::cpgrid::LevelGlobalIdSet; Not needed due to repeated code in LevelGlobalIdSet (computeId_cell and computeId_point)
         public:
-            typedef int IdType;
+            typedef std::int64_t IdType;
 
-            IdSet(const CpGridData& grid)
+            explicit IdSet(const CpGridData& grid)
                 : grid_(grid)
             {
             }
@@ -261,7 +264,7 @@ namespace Dune
                     // Level 1, 2, ...., maxLevel refined grids
                     if ( (gridIdx>0) && (gridIdx < static_cast<int>(grid_.levelData().size() -1)) ) {
                         if ((e.level() != gridIdx)) { // cells equiv to pre-existing cells
-                            return  grid_.levelData()[e.level()]->localIdSet().id(e.getEquivLevelElem());
+                            return  grid_.levelData()[e.level()]->localIdSet().id(e.getLevelElem());
                         }
                         else {
                             // Count (and add to myId) all the entities of all the codimensions (for CpGrid, only 0 and 3)
@@ -278,8 +281,7 @@ namespace Dune
                         assert( grid_.getGridIdx() == (static_cast<int>(grid_.levelData().size()) -1) );
                         // In this case, we search for the ids defined in previous levels
                         // (since each entities must keep its id along the entire hiearchy)
-                        std::array<int,2> level_levelIdx = {0,0};
-                        level_levelIdx = grid_.leaf_to_level_cells_[e.index()];
+                        const std::array<int,2> level_levelIdx = grid_.leaf_to_level_cells_[e.index()];
                         const auto& levelEntity =  cpgrid::Entity<0>(*(grid_.levelData()[level_levelIdx[0]]), level_levelIdx[1], true);
                         return  grid_.levelData()[level_levelIdx[0]]->local_id_set_ ->id(levelEntity);
                     }
@@ -329,8 +331,7 @@ namespace Dune
                         assert( grid_.getGridIdx() == (static_cast<int>(grid_.levelData().size()) -1) );
                         // In this case, we search for the ids defined in previous levels
                         // (since each entities must keep its id along the entire hiearchy)
-                        std::array<int,2> level_levelIdx = {0,0};
-                        level_levelIdx = grid_.corner_history_[e.index()];
+                        const std::array<int,2> level_levelIdx = grid_.corner_history_[e.index()];
                         const auto& levelEntity =  cpgrid::Entity<3>(*(grid_.levelData()[level_levelIdx[0]]), level_levelIdx[1], true);
                         return  grid_.levelData()[level_levelIdx[0]]->local_id_set_ ->id(levelEntity);
                     }
@@ -350,7 +351,7 @@ namespace Dune
             friend class CpGridData;
             friend class ReversePointGlobalIdSet;
         public:
-            typedef int IdType;
+            typedef std::int64_t IdType;
 
             void swap(std::vector<int>& cellMapping,
                       std::vector<int>& faceMapping,
@@ -362,7 +363,7 @@ namespace Dune
                                       pointMapping);
             }
             LevelGlobalIdSet(std::shared_ptr<const IdSet> ids, const CpGridData* view)
-                : idSet_(ids), view_(view)
+                : idSet_(std::move(ids)), view_(view)
             {}
             LevelGlobalIdSet()
                 : idSet_(), view_()
@@ -402,17 +403,35 @@ namespace Dune
             template<int codim>
             IdType getMaxCodimGlobalId()
             {
-                auto max_elem_codim = std::max_element(this->template getMapping<codim>().begin(),
-                                                       this->template getMapping<codim>().end());
-                return *max_elem_codim;
+                if(idSet_)
+                {
+                    IdType max_codim_id = 0;
+                    if (codim == 0) {
+                        for (int elemIdx = 0; elemIdx < view_-> size(0); ++elemIdx) {
+                            const auto& element=  cpgrid::Entity<0>(*view_, elemIdx, true);
+                            max_codim_id = std::max(max_codim_id, idSet_->id(element));
+                        }
+                    }
+                    if (codim == 3) {
+                        for (int pointIdx = 0; pointIdx < view_->size(3); ++pointIdx) {
+                            const auto& point =  cpgrid::Entity<3>(*view_, pointIdx, true);
+                            max_codim_id = std::max(max_codim_id, idSet_->id(point));
+                        }
+                    }
+                    return max_codim_id;
+                }
+                else  {
+                    // This a parallel grid and we need to use the mapping
+                    // build from the ids of the sequential grid
+                    auto max_elem_codim = std::max_element(this->template getMapping<codim>().begin(),
+                                                           this->template getMapping<codim>().end());
+                    return *max_elem_codim;
+                }
             }
 
             IdType getMaxGlobalId()
             {
-                /*// Ignore faces
-                auto max_globalId = std::max(getMaxCodimGlobalId<0>(), getMaxCodimGlobalId<1>());
-                max_globalId = std::max(max_globalId, getMaxCodimGlobalId<3>());
-                return max_globalId;*/
+                // Ignore faces
                 return std::max(getMaxCodimGlobalId<0>(), getMaxCodimGlobalId<3>());
             }
 
@@ -433,7 +452,7 @@ namespace Dune
         /// \brief The type of the id.
         using IdType = typename LevelGlobalIdSet::IdType;
 
-        GlobalIdSet(const CpGridData& view);
+        explicit GlobalIdSet(const CpGridData& view);
 
         template<int codim>
         IdType id(const Entity<codim>& e) const
@@ -465,7 +484,7 @@ namespace Dune
     class ReversePointGlobalIdSet
     {
     public:
-        ReversePointGlobalIdSet(const LevelGlobalIdSet& idSet)
+        explicit ReversePointGlobalIdSet(const LevelGlobalIdSet& idSet)
         {
             if(idSet.idSet_)
             {
