@@ -147,7 +147,6 @@ void refinePatch_and_check(Dune::CpGrid& coarse_grid,
             else{
                 BOOST_CHECK(lgr != -1);
                 // If it != endIt, then entity.isLeaf() false (when dristibuted_data_ is empty)
-                BOOST_CHECK_EQUAL( it == endIt, false);
                 BOOST_CHECK( entity.mightVanish() == true);
                 BOOST_CHECK( entity.isNew() == false);
                 BOOST_CHECK_EQUAL( entity.isLeaf(), false); // parent cells do not appear in the LeafView
@@ -502,7 +501,7 @@ void refinePatch_and_check(Dune::CpGrid& coarse_grid,
             allIds_set.insert(localId);
             allIds_vec.push_back(localId);
             // Check that the global_id_set_ptr_ has the correct id (id from the level where the entity was born).
-            BOOST_CHECK_EQUAL( coarse_grid.globalIdSet().id(element), data[element.level()]->localIdSet().id(element.getEquivLevelElem()));
+            BOOST_CHECK_EQUAL( coarse_grid.globalIdSet().id(element), data[element.level()]->localIdSet().id(element.getLevelElem()));
         }
         // Check injectivity of the map local_id_set_ (and, indirectly, global_id_set_) after adding cell ids.
         BOOST_CHECK( allIds_set.size() == allIds_vec.size());
@@ -537,7 +536,7 @@ void refinePatch_and_check(Dune::CpGrid& coarse_grid,
                                                   [localId, data](const Dune::cpgrid::Entity<0>& leafElem)
                                                   { return (localId == data.back()->localIdSet().id(leafElem)); });
                     itIsLeaf != elements(coarse_grid.leafGridView()).end()) {
-                    BOOST_CHECK( itIsLeaf->getEquivLevelElem() == element);
+                    BOOST_CHECK( itIsLeaf->getLevelElem() == element);
                 }
                 if (element.isLeaf()) { // Check that the id of a cell not involved in any further refinement appears on the IdSet of the leaf grid view.
                     BOOST_CHECK( std::find(allIds_set.begin(), allIds_set.end(), localId) != allIds_set.end());
