@@ -90,15 +90,12 @@ void testInactiveCellsLgrs(const std::string& deckString,
         BOOST_CHECK(data.size() == startIJK_vec.size() + 2);
         BOOST_CHECK( (*data[0]).child_to_parent_cells_.empty());
         BOOST_CHECK(grid.getLgrNameToLevel().at("GLOBAL") == 0);
-        const auto& all_parent_cell_indices = (*data[0]).getPatchesCells(startIJK_vec, endIJK_vec);
 
         for (long unsigned int level = 1; level < startIJK_vec.size() +1; ++level) // only 1 when there is only 1 patch
         {
             BOOST_CHECK( (*data[level]).parent_to_children_cells_.empty());
             BOOST_CHECK(grid.getLgrNameToLevel().at(lgr_name_vec[level-1]) == static_cast<int>(level));
 
-            const auto& patch_cells = (*data[0]).getPatchCells(startIJK_vec[level-1], endIJK_vec[level-1]);
-
             // GLOBAL grid
             for (int cell = 0; cell <  data[0]-> size(0); ++cell)
             {
@@ -321,7 +318,7 @@ void testInactiveCellsLgrs(const std::string& deckString,
             allIds_set.insert(localId);
             allIds_vec.push_back(localId);
             // Check that the global_id_set_ptr_ has the correct id (id from the level where the entity was born).
-            BOOST_CHECK_EQUAL( grid.globalIdSet().id(element), (*data[element.level()]).globalIdSet().id(element.getEquivLevelElem()));
+            BOOST_CHECK_EQUAL( grid.globalIdSet().id(element), (*data[element.level()]).globalIdSet().id(element.getLevelElem()));
         }
         // Check injectivity of the map local_id_set_ (and, indirectly, global_id_set_) after adding cell ids.
         BOOST_CHECK( allIds_set.size() == allIds_vec.size());
@@ -358,7 +355,7 @@ void testInactiveCellsLgrs(const std::string& deckString,
                                                   [localId, data](const Dune::cpgrid::Entity<0>& leafElem)
                                                   { return (localId == data.back()->localIdSet().id(leafElem)); });
                     itIsLeaf != elements(grid.leafGridView()).end()) {
-                    BOOST_CHECK( itIsLeaf->getEquivLevelElem() == element);
+                    BOOST_CHECK( itIsLeaf->getLevelElem() == element);
                 }
                 if (element.isLeaf()) { // Check that the id of a cell not involved in any further refinement appears on the IdSet of the leaf grid view.
                     BOOST_CHECK( std::find(allIds_set.begin(), allIds_set.end(), localId) != allIds_set.end());
